library(testthat)
library(tidySEM)
options("test_mplus" = FALSE)
test_check("tidySEM")
